@@ -1,7 +1,7 @@
 package Bencher::Scenario::BagComparison;
 
-our $DATE = '2016-10-19'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,7 +37,7 @@ Bencher::Scenario::BagComparison - Benchmark bag comparison
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::BagComparison (from Perl distribution Bencher-Scenario-BagComparison), released on 2016-10-19.
+This document describes version 0.003 of Bencher::Scenario::BagComparison (from Perl distribution Bencher-Scenario-BagComparison), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,7 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m BagComparison >>):
 
@@ -103,21 +103,24 @@ Benchmark with default options (C<< bencher -m BagComparison >>):
  +--------------+-----------+-----------+------------+-----------+---------+
  | dataset      | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +--------------+-----------+-----------+------------+-----------+---------+
- | elems=200num |       7.9 |    130    |        1   |   0.00018 |      20 |
- | elems=100num |      18   |     56    |        2.3 |   0.00012 |      21 |
- | elems=10num  |    1700   |      0.58 |      220   | 3.4e-06   |      20 |
+ | elems=200num |        11 |     90    |        1   |   0.00012 |      20 |
+ | elems=100num |        25 |     40    |        2.2 |   0.00018 |      21 |
+ | elems=10num  |      2500 |      0.41 |      220   | 4.2e-07   |      21 |
  +--------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m BagComparison --module-startup >>):
 
  #table2#
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Test::Deep          |        26 |                     21 |          1 | 4.4e-05 |      20 |
- | perl -e1 (baseline) |         5 |                      0 |          5 | 7.9e-05 |      20 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Test::Deep          | 0.82                         | 4.1                | 16             |      40   |                   34.5 |        1   | 6.1e-05 |      20 |
+ | perl -e1 (baseline) | 5.2                          | 8.6                | 24             |       5.5 |                    0   |        7.3 | 1.5e-05 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -145,7 +148,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
